@@ -413,6 +413,9 @@ bool DecodeOutputMD5::output(const SharedPtr<VideoFrame>& frame)
 {
     if (!setVideoSize(frame->crop.width, frame->crop.height))
         return false;
+    if (frame->fourcc == YAMI_FOURCC_P010)
+        m_convert.reset(new ColorConvert(m_vaDisplay, YAMI_FOURCC_P010));
+
     if (!m_convert->convert(m_data, frame))
         return false;
 
@@ -667,7 +670,7 @@ EGLImageKHR DecodeOutputDmabuf::createEGLImage(SharedPtr<VideoFrame>& frame)
     else if (m_memoryType == VIDEO_DATA_MEMORY_TYPE_DMA_BUF)
         m_bufferInfo.mem_type = VA_SURFACE_ATTRIB_MEM_TYPE_DRM_PRIME;
     status = vaAcquireBufferHandle(*m_vaDisplay, image.buf, &m_bufferInfo);
-    if (!checkVaapiStatus(status, "vaDeriveImage")) {
+    if (!checkVaapiStatus(status, "vaAcquireBufferHandle")) {
         vaDestroyImage(*m_vaDisplay, image.image_id);
         return eglImage;
     }
